==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/LoadBalancerFrontendIpConfigurationPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.LoadBalancerFrontendIpConfigurationPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes a cloud service IP Configuration
 * @property privateIPAddress The virtual network private IP address of the IP configuration.
 * @property publicIPAddress The reference to the public ip address resource.
 * @property subnet The reference to the virtual network subnet resource.
 */
public data class LoadBalancerFrontendIpConfigurationPropertiesArgs(
    public val privateIPAddress: Output<String>? = null,
    public val publicIPAddress: Output<SubResourceArgs>? = null,
    public val subnet: Output<SubResourceArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.LoadBalancerFrontendIpConfigurationPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.LoadBalancerFrontendIpConfigurationPropertiesArgs =
        com.pulumi.azurenative.compute.inputs.LoadBalancerFrontendIpConfigurationPropertiesArgs.builder()
            .privateIPAddress(privateIPAddress?.applyValue({ args0 -> args0 }))
            .publicIPAddress(publicIPAddress?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .subnet(subnet?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [LoadBalancerFrontendIpConfigurationPropertiesArgs].
 */
@PulumiTagMarker
public class LoadBalancerFrontendIpConfigurationPropertiesArgsBuilder internal constructor() {
    private var privateIPAddress: Output<String>? = null

    private var publicIPAddress: Output<SubResourceArgs>? = null

    private var subnet: Output<SubResourceArgs>? = null

    /**
     * @param value The virtual network private IP address of the IP configuration.
     */
    @JvmName("xjamcpdxncysqlxx")
    public suspend fun privateIPAddress(`value`: Output<String>) {
        this.privateIPAddress = value
    }

    /**
     * @param value The reference to the public ip address resource.
     */
    @JvmName("fpwqfsadevfengtj")
    public suspend fun publicIPAddress(`value`: Output<SubResourceArgs>) {
        this.publicIPAddress = value
    }

    /**
     * @param value The reference to the virtual network subnet resource.
     */
    @JvmName("sxgydcubbtjopvpn")
    public suspend fun subnet(`value`: Output<SubResourceArgs>) {
        this.subnet = value
    }

    /**
     * @param value The virtual network private IP address of the IP configuration.
     */
    @JvmName("wdmieylfllppnekw")
    public suspend fun privateIPAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateIPAddress = mapped
    }

    /**
     * @param value The reference to the public ip address resource.
     */
    @JvmName("cfncvaqcmuvkwvgi")
    public suspend fun publicIPAddress(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicIPAddress = mapped
    }

    /**
     * @param argument The reference to the public ip address resource.
     */
    @JvmName("jtwoghqybcrbbexe")
    public suspend fun publicIPAddress(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.publicIPAddress = mapped
    }

    /**
     * @param value The reference to the virtual network subnet resource.
     */
    @JvmName("ihxixverklpfbmnb")
    public suspend fun subnet(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnet = mapped
    }

    /**
     * @param argument The reference to the virtual network subnet resource.
     */
    @JvmName("rbiibfliteajflfv")
    public suspend fun subnet(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.subnet = mapped
    }

    internal fun build(): LoadBalancerFrontendIpConfigurationPropertiesArgs =
        LoadBalancerFrontendIpConfigurationPropertiesArgs(
            privateIPAddress = privateIPAddress,
            publicIPAddress = publicIPAddress,
            subnet = subnet,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/LoadBalancerFrontendIpConfigurationPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.LoadBalancerFrontendIpConfigurationPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes a cloud service IP Configuration
 * @property privateIPAddress The virtual network private IP address of the IP configuration.
 * @property publicIPAddress The reference to the public ip address resource.
 * @property subnet The reference to the virtual network subnet resource.
 */
public data class LoadBalancerFrontendIpConfigurationPropertiesArgs(
    public val privateIPAddress: Output<String>? = null,
    public val publicIPAddress: Output<SubResourceArgs>? = null,
    public val subnet: Output<SubResourceArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.LoadBalancerFrontendIpConfigurationPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.LoadBalancerFrontendIpConfigurationPropertiesArgs =
        com.pulumi.azurenative.compute.inputs.LoadBalancerFrontendIpConfigurationPropertiesArgs.builder()
            .privateIPAddress(privateIPAddress?.applyValue({ args0 -> args0 }))
            .publicIPAddress(publicIPAddress?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .subnet(subnet?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [LoadBalancerFrontendIpConfigurationPropertiesArgs].
 */
@PulumiTagMarker
public class LoadBalancerFrontendIpConfigurationPropertiesArgsBuilder internal constructor() {
    private var privateIPAddress: Output<String>? = null

    private var publicIPAddress: Output<SubResourceArgs>? = null

    private var subnet: Output<SubResourceArgs>? = null

    /**
     * @param value The virtual network private IP address of the IP configuration.
     */
    @JvmName("oprocfpketqvwbbo")
    public suspend fun privateIPAddress(`value`: Output<String>) {
        this.privateIPAddress = value
    }

    /**
     * @param value The reference to the public ip address resource.
     */
    @JvmName("nilvkcurthtelgnr")
    public suspend fun publicIPAddress(`value`: Output<SubResourceArgs>) {
        this.publicIPAddress = value
    }

    /**
     * @param value The reference to the virtual network subnet resource.
     */
    @JvmName("lgrydwuydyvmsrsq")
    public suspend fun subnet(`value`: Output<SubResourceArgs>) {
        this.subnet = value
    }

    /**
     * @param value The virtual network private IP address of the IP configuration.
     */
    @JvmName("pfexphvrtcexgibb")
    public suspend fun privateIPAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateIPAddress = mapped
    }

    /**
     * @param value The reference to the public ip address resource.
     */
    @JvmName("kcrtjtwiisraxdfw")
    public suspend fun publicIPAddress(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicIPAddress = mapped
    }

    /**
     * @param argument The reference to the public ip address resource.
     */
    @JvmName("brnldbfpxlxhdibo")
    public suspend fun publicIPAddress(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.publicIPAddress = mapped
    }

    /**
     * @param value The reference to the virtual network subnet resource.
     */
    @JvmName("gjxybquyffhxeqgt")
    public suspend fun subnet(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnet = mapped
    }

    /**
     * @param argument The reference to the virtual network subnet resource.
     */
    @JvmName("pliegbsshkofjdfs")
    public suspend fun subnet(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.subnet = mapped
    }

    internal fun build(): LoadBalancerFrontendIpConfigurationPropertiesArgs =
        LoadBalancerFrontendIpConfigurationPropertiesArgs(
            privateIPAddress = privateIPAddress,
            publicIPAddress = publicIPAddress,
            subnet = subnet,
        )
}
